==> solid-bootstrap-core-0.2.2.tgz: package/esm/TabPanel.jsx <==
import { mergeProps, useContext } from "solid-js";
import TabContext from "./TabContext";
import SelectableContext, { makeEventKey } from "./SelectableContext";
import NoopTransition from "./NoopTransition";
import { Dynamic } from "solid-js/web";
export function useTabPanel(props) {
    const context = useContext(TabContext);
    if (!context)
        return [
            props,
            {
                get eventKey() {
                    return props.eventKey;
                },
                get isActive() {
                    return props.active;
                },
                get mountOnEnter() {
                    return props.mountOnEnter;
                },
                get transition() {
                    return props.transition;
                },
                get unmountOnExit() {
                    return props.unmountOnExit;
                },
            },
        ];
    const key = makeEventKey(props.eventKey);
    const useTabPanel = mergeProps(props, {
        get id() {
            return context?.getControlledId(props.eventKey);
        },
        get "aria-labelledby"() {
            return context?.getControllerId(props.eventKey);
        },
    });
    return [
        useTabPanel,
        {
            get eventKey() {
                return props.eventKey;
            },
            get isActive() {
                return props.active == null && key != null
                    ? makeEventKey(context?.activeKey) === key
                    : props.active;
            },
            get transition() {
                return props.transition || context?.transition || NoopTransition;
            },
            get mountOnEnter() {
                return props.mountOnEnter != null
                    ? props.mountOnEnter
                    : context?.mountOnEnter;
            },
            get unmountOnExit() {
                return props.unmountOnExit != null
                    ? props.unmountOnExit
                    : context?.unmountOnExit;
            },
        },
    ];
}
const TabPanel = (props) => {
    const [tabPanelProps, other] = useTabPanel(props);
    const Transition = other.transition;
    // We provide an empty the TabContext so `<Nav>`s in `<TabPanel>`s don't
    // conflict with the top level one.
    return (<TabContext.Provider value={null}>
      <SelectableContext.Provider value={null}>
        {/* <Transition
          appear
          onBeforeExit={props.onBeforeExit}
          onExit={props.onExit}
          onAfterExit={props.onAfterExit}
          onBeforeEnter={props.onBeforeEnter}
          onEnter={props.onEnter}
          onAfterEnter={props.onAfterEnter}
        > */}
        <Dynamic component={(props.as ?? "div")} {...tabPanelProps} role="tabpanel" hidden={!other.isActive} aria-hidden={!other.isActive}>
          {tabPanelProps.children}
        </Dynamic>
        {/* </Transition> */}
      </SelectableContext.Provider>
    </TabContext.Provider>);
};
export default TabPanel;

==> solid-bootstrap-core-1.0.0.tgz: package/esm/TabPanel.jsx <==
import { mergeProps, useContext } from "solid-js";
import TabContext from "./TabContext";
import SelectableContext, { makeEventKey } from "./SelectableContext";
import NoopTransition from "./NoopTransition";
import { Dynamic } from "solid-js/web";
export function useTabPanel(props) {
    const context = useContext(TabContext);
    if (!context)
        return [
            props,
            {
                get eventKey() {
                    return props.eventKey;
                },
                get isActive() {
                    return props.active;
                },
                get mountOnEnter() {
                    return props.mountOnEnter;
                },
                get transition() {
                    return props.transition;
                },
                get unmountOnExit() {
                    return props.unmountOnExit;
                },
            },
        ];
    const key = makeEventKey(props.eventKey);
    const useTabPanel = mergeProps(props, {
        get id() {
            return context?.getControlledId(props.eventKey);
        },
        get "aria-labelledby"() {
            return context?.getControllerId(props.eventKey);
        },
    });
    return [
        useTabPanel,
        {
            get eventKey() {
                return props.eventKey;
            },
            get isActive() {
                return props.active == null && key != null
                    ? makeEventKey(context?.activeKey) === key
                    : props.active;
            },
            get transition() {
                return props.transition || context?.transition || NoopTransition;
            },
            get mountOnEnter() {
                return props.mountOnEnter != null ? props.mountOnEnter : context?.mountOnEnter;
            },
            get unmountOnExit() {
                return props.unmountOnExit != null ? props.unmountOnExit : context?.unmountOnExit;
            },
        },
    ];
}
const TabPanel = (props) => {
    const [tabPanelProps, other] = useTabPanel(props);
    const Transition = other.transition;
    // We provide an empty the TabContext so `<Nav>`s in `<TabPanel>`s don't
    // conflict with the top level one.
    return (<TabContext.Provider value={null}>
      <SelectableContext.Provider value={null}>
        {/* <Transition
          appear
          onBeforeExit={props.onBeforeExit}
          onExit={props.onExit}
          onAfterExit={props.onAfterExit}
          onBeforeEnter={props.onBeforeEnter}
          onEnter={props.onEnter}
          onAfterEnter={props.onAfterEnter}
        > */}
        <Dynamic component={(props.as ?? "div")} {...tabPanelProps} role="tabpanel" hidden={!other.isActive} aria-hidden={!other.isActive}>
          {tabPanelProps.children}
        </Dynamic>
        {/* </Transition> */}
      </SelectableContext.Provider>
    </TabContext.Provider>);
};
export default TabPanel;
